<template>
  <!-- 物资供应商信息添加 -->
  <div>
    <el-dialog
      :close-on-click-modal="false"
      :title="title + '物资供应商信息'"
      :visible.sync="showFormDia"
      width="60%"
      :before-close="handleClose"
      top="8vh"
    >
      <div>
        <el-form
          ref="formInfo"
          :rules="rules"
          :model="params"
          label-width="120px"
        >
          <p id="step1" class="from-title">
            <i class="el-icon-info" />
            <span>基础信息</span>
          </p>
          <el-row>
            <el-col :span="12">
              <el-form-item prop="name" label="供应商名称：">
                <el-input
                  v-model="params.name"
                  maxlength="80"
                  show-word-limit
                  placeholder="请输入供应商名称"
                />
              </el-form-item>
            </el-col>

            <el-col :span="12">
              <el-form-item label="地址：">
                <el-input
                  v-model="params.addr"
                  maxlength="80"
                  show-word-limit
                  placeholder="请输入地址"
                />
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="12">
              <el-form-item label="联系人：" prop="linkMan">
                <el-input
                  v-model="params.linkMan"
                  maxlength="10"
                  clearable
                  show-word-limit
                  placeholder="请输入联系人"
                />
              </el-form-item>
            </el-col>

            <el-col :span="12">
              <el-form-item label="联系电话：" prop="phone">
                <el-input
                  v-model="params.phone"
                  maxlength="20"
                  clearable
                  show-word-limit
                  placeholder="请输入联系电话"
                />
              </el-form-item>
            </el-col>
            <!-- <el-col :span="6">
                  <el-form-item label="邮箱" prop="email">
                    <el-input
                      v-model="params.email"
                      maxlength="24"
                      clearable
                      placeholder="请输入邮箱"
                    />
                  </el-form-item>
                </el-col> -->
          </el-row>
          <el-row>
            <el-col :span="24">
              <el-form-item label="备注：">
                <el-input
                  v-model="params.memo"
                  :rows="3"
                  maxlength="500"
                  show-word-limit
                  type="textarea"
                  style="width:100%;"
                />
              </el-form-item>
            </el-col>
          </el-row>
          <!-- <el-collapse v-model="activeCollapseNames" class="form-collapse">
            <el-collapse-item name="1">
              <template slot="title">
                <span class="collapse-title">
                  <i class="collapse-title-icon el-icon-info" />
                  基础信息
                </span>
              </template>
            </el-collapse-item>
          </el-collapse> -->
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" :loading="loading" @click="handleSave"
        >保 存</el-button
        >
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import CmgtMaterialCustomApi from '@/views/Manage/material/api/CmgtMaterialCustomApi'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CommonApi from '@/views/Manage/CommonApi.js'
import {mapState} from 'vuex'

export default {
  name: 'CmgtMaterialCustomFormDialog',
  components: {},
  props: {},
  data() {
    let validatePhone = (rule, value, callback) => {
      let phoneReg = /^1([3456789])\d{9}$/ // 手机
      if (!phoneReg.test(value) && value) {
        callback(new Error('联系电话不合法'))
      } else {
        callback()
      }
    }

    return {
      title: '新增',
      CommonApi,
      showFormDia: false,
      loading: false,
      activeCollapseNames: ['1'],
      activeTabChildName: '0',
      params: {
        name: null,
        linkMan: null,
        // email: null,
        phone: null,
        addr: null,
        memo: null
      },
      rules: {
        name: [
          {
            required: true,
            message: '请输入供应商名称',
            trigger: 'blur'
          }
        ],
        phone: [
          {
            validator: validatePhone,
            trigger: ['blur', 'change']
          }
        ]
      }
    }
  },
  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  created() {
  },
  methods: {
    add() {
      this.title = '新增'
      this.resetForm()
      this.showFormDia = true
    },
    resetForm() {
      this.params = {
        name: null,
        linkMan: null,
        // email: null,
        phone: null,
        addr: null,
        memo: null
      }
    },
    handleClose() {
      this.$refs.formInfo.clearValidate()
      this.resetForm()
      this.showFormDia = false
    },
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          let method
          if (!this.params.id) {
            // 新增
            method = CmgtMaterialCustomApi.addCmgtMaterialCustom
          } else {
            // 修改
            method = CmgtMaterialCustomApi.editCmgtMaterialCustom
          }
          this.loading = true
          method(this.params, res => {
            this.loading = false
            if (res.state) {
              this.$notify({
                type: 'success',
                message: this.title + '成功',
                duration: 2000
              })
              // this.$emit('loadData')
              this.$parent.loadData()
              this.handleClose()
            } else {
              this.$message.warning(res.message)
            }
          })
        }
      })
    },
    Update(row) {
      this.title = '修改'
      this.showFormDia = true
      this.params = row
    }
  }
}
</script>
<style lang="scss" scoped>
.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}
</style>
